pub struct NewEvents<E>where
E: Event,{ /* private fields */ }Expand description
Collection of new events produced by a command.
This type represents the output of CommandLogic::handle() - the
events that should be persisted as a result of command execution.
Per ADR-012, this works with domain event types that implement the Event trait.