pub struct RetryCount(/* private fields */);Expand description
Count of retry attempts that have been made (0-based).
RetryCount represents how many retry attempts have been made so far. Starts at 0 on the initial failure (before any retries).
Examples
ⓘ
use eventcore_types::projection::RetryCount;
let initial_failure = RetryCount::new(0);
let after_first_retry = RetryCount::new(1);
let after_three_retries = RetryCount::new(3);Implementations
Sourceimpl RetryCount
impl RetryCount
pub fn new(raw_value: u32) -> RetryCount
Sourceimpl RetryCount
impl RetryCount
pub fn into_inner(self) -> u32